# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: th2_grpc_util/util.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from th2_grpc_common import common_pb2 as th2__grpc__common_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='th2_grpc_util/util.proto',
  package='util',
  syntax='proto3',
  serialized_options=b'\n\032com.exactpro.th2.util.grpcP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18th2_grpc_util/util.proto\x12\x04util\x1a\x1cth2_grpc_common/common.proto\"+\n\x12\x43omparisonSettings\x12\x15\n\rignore_fields\x18\x01 \x03(\t\"\x88\x01\n\x1e\x43ompareFilterVsMessagesRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.MessageFilter\x12\x1a\n\x08messages\x18\x02 \x03(\x0b\x32\x08.Message\x12*\n\x08settings\x18\x03 \x01(\x0b\x32\x18.util.ComparisonSettings\"a\n\x1f\x43ompareFilterVsMessagesResponse\x12>\n\x12\x63omparison_results\x18\x01 \x03(\x0b\x32\".util.CompareFilterVsMessageResult\"p\n\x1c\x43ompareFilterVsMessageResult\x12\x1e\n\nmessage_id\x18\x01 \x01(\x0b\x32\n.MessageID\x12\x30\n\x11\x63omparison_result\x18\x02 \x01(\x0b\x32\x15.util.ComparisonEntry\"]\n\x1e\x43ompareMessageVsMessageRequest\x12;\n\x10\x63omparison_tasks\x18\x01 \x03(\x0b\x32!.util.CompareMessageVsMessageTask\"b\n\x1f\x43ompareMessageVsMessageResponse\x12?\n\x12\x63omparison_results\x18\x01 \x03(\x0b\x32#.util.CompareMessageVsMessageResult\"|\n\x1b\x43ompareMessageVsMessageTask\x12\x17\n\x05\x66irst\x18\x01 \x01(\x0b\x32\x08.Message\x12\x18\n\x06second\x18\x02 \x01(\x0b\x32\x08.Message\x12*\n\x08settings\x18\x03 \x01(\x0b\x32\x18.util.ComparisonSettings\"\x9e\x01\n\x1d\x43ompareMessageVsMessageResult\x12$\n\x10\x66irst_message_id\x18\x01 \x01(\x0b\x32\n.MessageID\x12%\n\x11second_message_id\x18\x02 \x01(\x0b\x32\n.MessageID\x12\x30\n\x11\x63omparison_result\x18\x03 \x01(\x0b\x32\x15.util.ComparisonEntry\"\xb4\x02\n\x0f\x43omparisonEntry\x12\'\n\x04type\x18\x01 \x01(\x0e\x32\x19.util.ComparisonEntryType\x12+\n\x06status\x18\x02 \x01(\x0e\x32\x1b.util.ComparisonEntryStatus\x12\r\n\x05\x66irst\x18\x03 \x01(\t\x12\x0e\n\x06second\x18\x04 \x01(\t\x12#\n\toperation\x18\x05 \x01(\x0e\x32\x10.FilterOperation\x12\x0e\n\x06is_key\x18\x06 \x01(\x08\x12\x31\n\x06\x66ields\x18\x07 \x03(\x0b\x32!.util.ComparisonEntry.FieldsEntry\x1a\x44\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.util.ComparisonEntry:\x02\x38\x01*0\n\x13\x43omparisonEntryType\x12\t\n\x05\x46IELD\x10\x00\x12\x0e\n\nCOLLECTION\x10\x01*7\n\x15\x43omparisonEntryStatus\x12\x06\n\x02NA\x10\x00\x12\n\n\x06PASSED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\x32\xe3\x01\n\x11MessageComparator\x12\x66\n\x17\x63ompareFilterVsMessages\x12$.util.CompareFilterVsMessagesRequest\x1a%.util.CompareFilterVsMessagesResponse\x12\x66\n\x17\x63ompareMessageVsMessage\x12$.util.CompareMessageVsMessageRequest\x1a%.util.CompareMessageVsMessageResponseB\x1e\n\x1a\x63om.exactpro.th2.util.grpcP\x01\x62\x06proto3'
  ,
  dependencies=[th2__grpc__common_dot_common__pb2.DESCRIPTOR,])

_COMPARISONENTRYTYPE = _descriptor.EnumDescriptor(
  name='ComparisonEntryType',
  full_name='util.ComparisonEntryType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FIELD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COLLECTION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1254,
  serialized_end=1302,
)
_sym_db.RegisterEnumDescriptor(_COMPARISONENTRYTYPE)

ComparisonEntryType = enum_type_wrapper.EnumTypeWrapper(_COMPARISONENTRYTYPE)
_COMPARISONENTRYSTATUS = _descriptor.EnumDescriptor(
  name='ComparisonEntryStatus',
  full_name='util.ComparisonEntryStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NA', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PASSED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1304,
  serialized_end=1359,
)
_sym_db.RegisterEnumDescriptor(_COMPARISONENTRYSTATUS)

ComparisonEntryStatus = enum_type_wrapper.EnumTypeWrapper(_COMPARISONENTRYSTATUS)
FIELD = 0
COLLECTION = 1
NA = 0
PASSED = 1
FAILED = 2



_COMPARISONSETTINGS = _descriptor.Descriptor(
  name='ComparisonSettings',
  full_name='util.ComparisonSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ignore_fields', full_name='util.ComparisonSettings.ignore_fields', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=107,
)


_COMPAREFILTERVSMESSAGESREQUEST = _descriptor.Descriptor(
  name='CompareFilterVsMessagesRequest',
  full_name='util.CompareFilterVsMessagesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='util.CompareFilterVsMessagesRequest.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='util.CompareFilterVsMessagesRequest.messages', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='util.CompareFilterVsMessagesRequest.settings', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=110,
  serialized_end=246,
)


_COMPAREFILTERVSMESSAGESRESPONSE = _descriptor.Descriptor(
  name='CompareFilterVsMessagesResponse',
  full_name='util.CompareFilterVsMessagesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='comparison_results', full_name='util.CompareFilterVsMessagesResponse.comparison_results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=248,
  serialized_end=345,
)


_COMPAREFILTERVSMESSAGERESULT = _descriptor.Descriptor(
  name='CompareFilterVsMessageResult',
  full_name='util.CompareFilterVsMessageResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_id', full_name='util.CompareFilterVsMessageResult.message_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comparison_result', full_name='util.CompareFilterVsMessageResult.comparison_result', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=459,
)


_COMPAREMESSAGEVSMESSAGEREQUEST = _descriptor.Descriptor(
  name='CompareMessageVsMessageRequest',
  full_name='util.CompareMessageVsMessageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='comparison_tasks', full_name='util.CompareMessageVsMessageRequest.comparison_tasks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=461,
  serialized_end=554,
)


_COMPAREMESSAGEVSMESSAGERESPONSE = _descriptor.Descriptor(
  name='CompareMessageVsMessageResponse',
  full_name='util.CompareMessageVsMessageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='comparison_results', full_name='util.CompareMessageVsMessageResponse.comparison_results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=556,
  serialized_end=654,
)


_COMPAREMESSAGEVSMESSAGETASK = _descriptor.Descriptor(
  name='CompareMessageVsMessageTask',
  full_name='util.CompareMessageVsMessageTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='first', full_name='util.CompareMessageVsMessageTask.first', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='second', full_name='util.CompareMessageVsMessageTask.second', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='util.CompareMessageVsMessageTask.settings', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=656,
  serialized_end=780,
)


_COMPAREMESSAGEVSMESSAGERESULT = _descriptor.Descriptor(
  name='CompareMessageVsMessageResult',
  full_name='util.CompareMessageVsMessageResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='first_message_id', full_name='util.CompareMessageVsMessageResult.first_message_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='second_message_id', full_name='util.CompareMessageVsMessageResult.second_message_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comparison_result', full_name='util.CompareMessageVsMessageResult.comparison_result', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=783,
  serialized_end=941,
)


_COMPARISONENTRY_FIELDSENTRY = _descriptor.Descriptor(
  name='FieldsEntry',
  full_name='util.ComparisonEntry.FieldsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='util.ComparisonEntry.FieldsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='util.ComparisonEntry.FieldsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1184,
  serialized_end=1252,
)

_COMPARISONENTRY = _descriptor.Descriptor(
  name='ComparisonEntry',
  full_name='util.ComparisonEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='util.ComparisonEntry.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='util.ComparisonEntry.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first', full_name='util.ComparisonEntry.first', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='second', full_name='util.ComparisonEntry.second', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation', full_name='util.ComparisonEntry.operation', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_key', full_name='util.ComparisonEntry.is_key', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fields', full_name='util.ComparisonEntry.fields', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_COMPARISONENTRY_FIELDSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=944,
  serialized_end=1252,
)

_COMPAREFILTERVSMESSAGESREQUEST.fields_by_name['filter'].message_type = th2__grpc__common_dot_common__pb2._MESSAGEFILTER
_COMPAREFILTERVSMESSAGESREQUEST.fields_by_name['messages'].message_type = th2__grpc__common_dot_common__pb2._MESSAGE
_COMPAREFILTERVSMESSAGESREQUEST.fields_by_name['settings'].message_type = _COMPARISONSETTINGS
_COMPAREFILTERVSMESSAGESRESPONSE.fields_by_name['comparison_results'].message_type = _COMPAREFILTERVSMESSAGERESULT
_COMPAREFILTERVSMESSAGERESULT.fields_by_name['message_id'].message_type = th2__grpc__common_dot_common__pb2._MESSAGEID
_COMPAREFILTERVSMESSAGERESULT.fields_by_name['comparison_result'].message_type = _COMPARISONENTRY
_COMPAREMESSAGEVSMESSAGEREQUEST.fields_by_name['comparison_tasks'].message_type = _COMPAREMESSAGEVSMESSAGETASK
_COMPAREMESSAGEVSMESSAGERESPONSE.fields_by_name['comparison_results'].message_type = _COMPAREMESSAGEVSMESSAGERESULT
_COMPAREMESSAGEVSMESSAGETASK.fields_by_name['first'].message_type = th2__grpc__common_dot_common__pb2._MESSAGE
_COMPAREMESSAGEVSMESSAGETASK.fields_by_name['second'].message_type = th2__grpc__common_dot_common__pb2._MESSAGE
_COMPAREMESSAGEVSMESSAGETASK.fields_by_name['settings'].message_type = _COMPARISONSETTINGS
_COMPAREMESSAGEVSMESSAGERESULT.fields_by_name['first_message_id'].message_type = th2__grpc__common_dot_common__pb2._MESSAGEID
_COMPAREMESSAGEVSMESSAGERESULT.fields_by_name['second_message_id'].message_type = th2__grpc__common_dot_common__pb2._MESSAGEID
_COMPAREMESSAGEVSMESSAGERESULT.fields_by_name['comparison_result'].message_type = _COMPARISONENTRY
_COMPARISONENTRY_FIELDSENTRY.fields_by_name['value'].message_type = _COMPARISONENTRY
_COMPARISONENTRY_FIELDSENTRY.containing_type = _COMPARISONENTRY
_COMPARISONENTRY.fields_by_name['type'].enum_type = _COMPARISONENTRYTYPE
_COMPARISONENTRY.fields_by_name['status'].enum_type = _COMPARISONENTRYSTATUS
_COMPARISONENTRY.fields_by_name['operation'].enum_type = th2__grpc__common_dot_common__pb2._FILTEROPERATION
_COMPARISONENTRY.fields_by_name['fields'].message_type = _COMPARISONENTRY_FIELDSENTRY
DESCRIPTOR.message_types_by_name['ComparisonSettings'] = _COMPARISONSETTINGS
DESCRIPTOR.message_types_by_name['CompareFilterVsMessagesRequest'] = _COMPAREFILTERVSMESSAGESREQUEST
DESCRIPTOR.message_types_by_name['CompareFilterVsMessagesResponse'] = _COMPAREFILTERVSMESSAGESRESPONSE
DESCRIPTOR.message_types_by_name['CompareFilterVsMessageResult'] = _COMPAREFILTERVSMESSAGERESULT
DESCRIPTOR.message_types_by_name['CompareMessageVsMessageRequest'] = _COMPAREMESSAGEVSMESSAGEREQUEST
DESCRIPTOR.message_types_by_name['CompareMessageVsMessageResponse'] = _COMPAREMESSAGEVSMESSAGERESPONSE
DESCRIPTOR.message_types_by_name['CompareMessageVsMessageTask'] = _COMPAREMESSAGEVSMESSAGETASK
DESCRIPTOR.message_types_by_name['CompareMessageVsMessageResult'] = _COMPAREMESSAGEVSMESSAGERESULT
DESCRIPTOR.message_types_by_name['ComparisonEntry'] = _COMPARISONENTRY
DESCRIPTOR.enum_types_by_name['ComparisonEntryType'] = _COMPARISONENTRYTYPE
DESCRIPTOR.enum_types_by_name['ComparisonEntryStatus'] = _COMPARISONENTRYSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ComparisonSettings = _reflection.GeneratedProtocolMessageType('ComparisonSettings', (_message.Message,), {
  'DESCRIPTOR' : _COMPARISONSETTINGS,
  '__module__' : 'th2_grpc_util.util_pb2'
  # @@protoc_insertion_point(class_scope:util.ComparisonSettings)
  })
_sym_db.RegisterMessage(ComparisonSettings)

CompareFilterVsMessagesRequest = _reflection.GeneratedProtocolMessageType('CompareFilterVsMessagesRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPAREFILTERVSMESSAGESREQUEST,
  '__module__' : 'th2_grpc_util.util_pb2'
  # @@protoc_insertion_point(class_scope:util.CompareFilterVsMessagesRequest)
  })
_sym_db.RegisterMessage(CompareFilterVsMessagesRequest)

CompareFilterVsMessagesResponse = _reflection.GeneratedProtocolMessageType('CompareFilterVsMessagesResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMPAREFILTERVSMESSAGESRESPONSE,
  '__module__' : 'th2_grpc_util.util_pb2'
  # @@protoc_insertion_point(class_scope:util.CompareFilterVsMessagesResponse)
  })
_sym_db.RegisterMessage(CompareFilterVsMessagesResponse)

CompareFilterVsMessageResult = _reflection.GeneratedProtocolMessageType('CompareFilterVsMessageResult', (_message.Message,), {
  'DESCRIPTOR' : _COMPAREFILTERVSMESSAGERESULT,
  '__module__' : 'th2_grpc_util.util_pb2'
  # @@protoc_insertion_point(class_scope:util.CompareFilterVsMessageResult)
  })
_sym_db.RegisterMessage(CompareFilterVsMessageResult)

CompareMessageVsMessageRequest = _reflection.GeneratedProtocolMessageType('CompareMessageVsMessageRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPAREMESSAGEVSMESSAGEREQUEST,
  '__module__' : 'th2_grpc_util.util_pb2'
  # @@protoc_insertion_point(class_scope:util.CompareMessageVsMessageRequest)
  })
_sym_db.RegisterMessage(CompareMessageVsMessageRequest)

CompareMessageVsMessageResponse = _reflection.GeneratedProtocolMessageType('CompareMessageVsMessageResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMPAREMESSAGEVSMESSAGERESPONSE,
  '__module__' : 'th2_grpc_util.util_pb2'
  # @@protoc_insertion_point(class_scope:util.CompareMessageVsMessageResponse)
  })
_sym_db.RegisterMessage(CompareMessageVsMessageResponse)

CompareMessageVsMessageTask = _reflection.GeneratedProtocolMessageType('CompareMessageVsMessageTask', (_message.Message,), {
  'DESCRIPTOR' : _COMPAREMESSAGEVSMESSAGETASK,
  '__module__' : 'th2_grpc_util.util_pb2'
  # @@protoc_insertion_point(class_scope:util.CompareMessageVsMessageTask)
  })
_sym_db.RegisterMessage(CompareMessageVsMessageTask)

CompareMessageVsMessageResult = _reflection.GeneratedProtocolMessageType('CompareMessageVsMessageResult', (_message.Message,), {
  'DESCRIPTOR' : _COMPAREMESSAGEVSMESSAGERESULT,
  '__module__' : 'th2_grpc_util.util_pb2'
  # @@protoc_insertion_point(class_scope:util.CompareMessageVsMessageResult)
  })
_sym_db.RegisterMessage(CompareMessageVsMessageResult)

ComparisonEntry = _reflection.GeneratedProtocolMessageType('ComparisonEntry', (_message.Message,), {

  'FieldsEntry' : _reflection.GeneratedProtocolMessageType('FieldsEntry', (_message.Message,), {
    'DESCRIPTOR' : _COMPARISONENTRY_FIELDSENTRY,
    '__module__' : 'th2_grpc_util.util_pb2'
    # @@protoc_insertion_point(class_scope:util.ComparisonEntry.FieldsEntry)
    })
  ,
  'DESCRIPTOR' : _COMPARISONENTRY,
  '__module__' : 'th2_grpc_util.util_pb2'
  # @@protoc_insertion_point(class_scope:util.ComparisonEntry)
  })
_sym_db.RegisterMessage(ComparisonEntry)
_sym_db.RegisterMessage(ComparisonEntry.FieldsEntry)


DESCRIPTOR._options = None
_COMPARISONENTRY_FIELDSENTRY._options = None

_MESSAGECOMPARATOR = _descriptor.ServiceDescriptor(
  name='MessageComparator',
  full_name='util.MessageComparator',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1362,
  serialized_end=1589,
  methods=[
  _descriptor.MethodDescriptor(
    name='compareFilterVsMessages',
    full_name='util.MessageComparator.compareFilterVsMessages',
    index=0,
    containing_service=None,
    input_type=_COMPAREFILTERVSMESSAGESREQUEST,
    output_type=_COMPAREFILTERVSMESSAGESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='compareMessageVsMessage',
    full_name='util.MessageComparator.compareMessageVsMessage',
    index=1,
    containing_service=None,
    input_type=_COMPAREMESSAGEVSMESSAGEREQUEST,
    output_type=_COMPAREMESSAGEVSMESSAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MESSAGECOMPARATOR)

DESCRIPTOR.services_by_name['MessageComparator'] = _MESSAGECOMPARATOR

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from th2_grpc_util import util_pb2 as th2__grpc__util_dot_util__pb2


class MessageComparatorStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.compareFilterVsMessages = channel.unary_unary(
                '/util.MessageComparator/compareFilterVsMessages',
                request_serializer=th2__grpc__util_dot_util__pb2.CompareFilterVsMessagesRequest.SerializeToString,
                response_deserializer=th2__grpc__util_dot_util__pb2.CompareFilterVsMessagesResponse.FromString,
                )
        self.compareMessageVsMessage = channel.unary_unary(
                '/util.MessageComparator/compareMessageVsMessage',
                request_serializer=th2__grpc__util_dot_util__pb2.CompareMessageVsMessageRequest.SerializeToString,
                response_deserializer=th2__grpc__util_dot_util__pb2.CompareMessageVsMessageResponse.FromString,
                )


class MessageComparatorServicer(object):
    """Missing associated documentation comment in .proto file."""

    def compareFilterVsMessages(self, request, context):
        """Compares a filter vs passed messages and returns comparison result for every pair.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def compareMessageVsMessage(self, request, context):
        """Compares a message vs another message and returns a comparison result.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MessageComparatorServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'compareFilterVsMessages': grpc.unary_unary_rpc_method_handler(
                    servicer.compareFilterVsMessages,
                    request_deserializer=th2__grpc__util_dot_util__pb2.CompareFilterVsMessagesRequest.FromString,
                    response_serializer=th2__grpc__util_dot_util__pb2.CompareFilterVsMessagesResponse.SerializeToString,
            ),
            'compareMessageVsMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.compareMessageVsMessage,
                    request_deserializer=th2__grpc__util_dot_util__pb2.CompareMessageVsMessageRequest.FromString,
                    response_serializer=th2__grpc__util_dot_util__pb2.CompareMessageVsMessageResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'util.MessageComparator', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MessageComparator(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def compareFilterVsMessages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/util.MessageComparator/compareFilterVsMessages',
            th2__grpc__util_dot_util__pb2.CompareFilterVsMessagesRequest.SerializeToString,
            th2__grpc__util_dot_util__pb2.CompareFilterVsMessagesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def compareMessageVsMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/util.MessageComparator/compareMessageVsMessage',
            th2__grpc__util_dot_util__pb2.CompareMessageVsMessageRequest.SerializeToString,
            th2__grpc__util_dot_util__pb2.CompareMessageVsMessageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
